@@ -1,7 +1,10 @@
+# MIT licensed
+# Copyright (c) 2013-2017 lilydjwg <lilydjwg@gmail.com>, et al.
+
 from .simple_json import simple_json
 
 # Using metacpan
-CPAN_URL = 'https://api.metacpan.org/release/%s'
+CPAN_URL = 'https://fastapi.metacpan.org/release/%s'
 
 def _version_from_json(data):
   return str(data['version'])
